from win32com.shell import shell, shellcon
import pythoncom
import os


def getDesktopPath():
    path = shell.SHGetFolderPath(0, shellcon.CSIDL_DESKTOP, 0, 0)
    if os.path.exists(path):
        return path
    else:
        return None


def getMenuPath():
    path = shell.SHGetSpecialFolderPath(0, shellcon.CSIDL_STARTMENU)
    if os.path.exists(path):
        return path
    else:
        return None


class WindowsShortcut:
    def __init__(self, path, name, execFile):
        self.execFile = execFile
        self.name = name
        self.path = os.path.join(path, name) + ".lnk"
        self.file = pythoncom.CoCreateInstance(shell.CLSID_ShellLink, None, pythoncom.CLSCTX_INPROC_SERVER, shell.IID_IShellLink)
        if os.path.exists(self.execFile):
            self.file.SetPath(self.execFile)
        self.working = None
    
    def setWorkingDirectory(self, directory):
        self.file.SetWorkingDirectory(directory)
        self.working = directory

    def setComment(self, comment):
        self.file.SetDescription(comment)

    def setIcon(self, pathToIcon, index = 0):
        self.file.SetIconLocation(pathToIcon, index)
    
    def setCategories(self, categories):
        pass

    def setTitle(self, title):
        pass
    
    def save(self):
        if not os.path.exists(self.execFile):
            if self.working != None:
                path = self.working
            else:
                path = "."
            path = os.path.join(path, self.name + ".bat")
            count = 0
            while os.path.exists(path):
                count += 1
                path = os.path.join(os.path.dirname(path), self.name + str(count) + ".bat")
            file = open(path, "w")
            file.write(self.execFile)
            file.close()
            self.file.SetPath(path)
        file = self.file.QueryInterface(pythoncom.IID_IPersistFile)
        file.Save(self.path, 0)



import os


def getDesktopPath():
    try:
        path = os.popen("xdg-user-dir DESKTOP").read()
    except:
        path = os.path.expanduser("~/Desktop")
    stringList = list(path)
    while stringList[-1] == "\n":
        del stringList[-1]
    path = ""
    for i in stringList:
        path += i
    if os.path.exists(path):
        return path
    else:
        return None


def getMenuPath():
    path = os.path.expanduser("~/.local/share/applications")
    if os.path.exists(path):
        return path
    else:
        path = "/usr/local/share/applications"
        if os.path.exists(path):
            return path
        else:
            path = "/usr/share/applications"
            if os.path.exists(path):
                return path
            else:
                return None


class LinuxShortcut:
    def __init__(self, path, name, execFile):
        self.execFile = execFile
        self.name = name
        self.path = os.path.join(path, name) + ".desktop"
        self.file = open(self.path, "w")
        self.file.write("[Desktop Entry]\nType=Application\nExec=" + self.execFile + "\n")
        self.attributes = {"Path": None, "Comment": None, "Icon": None, "Categories": None, "Name": self.name}
    
    def setWorkingDirectory(self, directory):
        self.attributes["Path"] = directory

    def setComment(self, comment, lang=False):
        if lang:
            self.attributes[f"Comment[{lang}]"] = comment
        else:
            self.attributes["Comment"] = comment

    def setIcon(self, pathToIcon, index = 0):
        self.attributes["Icon"] = pathToIcon
    
    def setCategories(self, categories):
        self.attributes["Categories"] = categories

    def setTitle(self, title, lang=False):
        if lang:
            self.attributes[f"Name[{lang}]"] = title
        else:
            self.attributes["Name"] = title
    
    def save(self):
        for attrib, value in self.attributes.items():
            if value != None:
                self.file.write(attrib + "=" + value + "\n")
        self.file.close()



from setuptools import setup

setup(
    name = "desktop_file",
    version = "1.3",
    packages = ["desktop_file"],
    license = "MIT",
    include_package_data = True,
    author = "PyRectangle",
    author_email = "PyRectangle@web.de",
    url = "https://github.com/PyRectangle/DesktopFile",
    scripts = ["desktop-file"],
    description = "desktop-file is a tool to create desktop shortcuts for windows and linux.",
    install_requires=['pypiwin32; platform_system == "Windows"'],
    long_description = open('README.md').read(),
    long_description_content_type='text/markdown'
)
